/*
    mikroc_arm.h

-----------------------------------------------------------------------------

  This file is part of mikroSDK.
  
  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

/**
        \file   mikroc_arm.h

- Version               :   1.0.0
- Date                  :   May 2019
- Developer             :   Milos Vidojevic

---

    Toolchain specific types related to low level HW access functions. 

*/
/* -------------------------------------------------------------------------- */

#ifndef _MIKROC_ARM_H_
#define _MIKROC_ARM_H_

//#include "__Lib_GPIO.h"

// ============================================================================
//                                                                      STM32
// ============================================================================

#define _INSTRUCTION_PER_CLOCK      1

#ifdef __STM32__

typedef void            ( * hal_spi_write_fp_t )    ( unsigned int );
typedef unsigned int    ( * hal_spi_read_fp_t )     ( unsigned int );

typedef struct
{
    hal_spi_write_fp_t       spi_write;
    hal_spi_read_fp_t        spi_read;
  
} hal_spi_obj_t;

typedef unsigned int    ( * hal_i2c_start_fp_t )    ( void );                       
typedef unsigned int    ( * hal_i2c_write_fp_t )    ( unsigned char, unsigned char *, unsigned long, unsigned long );
typedef void            ( * hal_i2c_read_fp_t )     ( unsigned char, unsigned char *, unsigned long, unsigned long );

typedef struct
{
    hal_i2c_start_fp_t       i2c_start;
    hal_i2c_write_fp_t       i2c_write;
    hal_i2c_read_fp_t        i2c_read;
  
} hal_i2c_obj_t;

typedef void            ( * hal_uart_write_fp_t )   ( unsigned int );
typedef unsigned int    ( * hal_uart_read_fp_t )    ( void );
typedef unsigned int    ( * hal_uart_ready_fp_t )   ( void );

typedef struct
{
    hal_uart_write_fp_t      uart_write;
    hal_uart_read_fp_t       uart_read;
    hal_uart_ready_fp_t      uart_ready;
  
} hal_uart_obj_t;

typedef void            ( * hal_pwm_duty_fp_t )     ( unsigned int, char, char );
typedef void            ( * hal_pwm_stop_fp_t )     ( char );

typedef struct
{
    hal_pwm_duty_fp_t       pwm_duty;
    hal_pwm_stop_fp_t       pwm_stop;
  
} hal_pwm_obj_t;

typedef unsigned int    ( * hal_adc_read_fp_t )     ( unsigned int );
typedef unsigned int    ( * hal_adc_sample_fp_t )   ( unsigned int );

typedef struct
{
    hal_adc_read_fp_t       adc_read;
    hal_adc_sample_fp_t     adc_sample;
  
} hal_adc_obj_t;

#endif

#endif

/* -------------------------------------------------------------------------- */
/*
    mikroc_arm.h

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgment:
   This product includes software developed by the MikroElektonika.

4. Neither the name of the MikroElektonika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */