#include "indoor_module.h"

/* ------------------------------------------------------------------- MACROS */



/* ---------------------------------------------------------------- VARIABLES */

static module_t         indoor_module;

#if (_MMB_MODULE_TEMP == 1)

    /**
     * Temperature sensor scecific variable
     */
    static float temperature;

#endif

#if (_MMB_MODULE_ALS == 1)

    /**
     * ALS specific variables
     */
    static uint8_t ALS_CTRL_REG = 0x01;
    static uint8_t ALS_MEAS_REG = 0x12;
    static uint8_t als_manufac_id;
    static uint8_t als_part_id;
    static uint16_t channel_0;
    static uint16_t channel_1;

#endif

/**
 * General variables
 */
static char text[50];
static uint16_t i;

/* -------------------------------------------- PRIVATE FUNCTION DECLARATIONS */

/**
 * This function rounds floating point value converted to string to two decimal places
 * !!! text[]- buffer must be 30 byte size !!!
 */
static void float_cut( char * text );

/* ----------------------------------------------------------- IMPLEMENTATION */

void indoor_module_init ( module_t ** module )
{
    /**
    * Set indoor module state to inactive
    */
    indoor_module.state = MODULE_INACTIVE;

    #if (_MMB_MODULE_TEMP == 1)

        /**
         * Initialize temperature device
         */
        bsp_temperature_init( );

    #endif

    #if (_MMB_MODULE_ALS == 1)

        /**
         * Initialize als device
         */
        bsp_als_init( );

        /**
         * Configure als device
         */
        bsp_als_write_regs( _BSP_ALS_CONTR_REG,      &ALS_CTRL_REG,   1 );
        bsp_als_write_regs( _BSP_ALS_MEAS_REG,       &ALS_MEAS_REG,   1 );
        bsp_als_read_regs(  _BSP_ALS_MANUFAC_ID_REG, &als_manufac_id, 1 );
        bsp_als_read_regs(  _BSP_ALS_PART_ID_REG,    &als_part_id,    1 );

    #endif

    /**
    * Initialize indoor module
    */
    *module = &indoor_module;
}

void indoor_module_task ( void )
{
    switch ( indoor_module.state )
    {
        case MODULE_INACTIVE :
        {
            /**
             * Draw screen elements
             */
            DrawImage( &Image_00_02_INDOOR );

            /**
             * Set indoor module state to active
             */
            indoor_module.state = MODULE_ACTIVE;

            /**
             * Refresh rate
             */
            i = 5000;

            break;
        }
        case MODULE_ACTIVE :
        {
            #if (( _MMB_MODULE_TEMP == 1 ) && ( _MMB_MODULE_ALS == 1 ))

                if (i == 5000)
                {
                    i = 0;

                    /**
                     * Get new temperature and als values
                     */
                    temperature = bsp_temperature_read( );
                    bsp_als_read_measurement( &channel_0, &channel_1 );
                    
                    /**
                     * Clear all temperature and als labels
                     */
                    Label_00_00_Indoor_Temperature.Font_Color = CL_WHITE;
                    Label_00_01_Indoor_Ambient_Light_CH0.Font_Color = CL_WHITE;
                    Label_00_01_Indoor_Ambient_Light_CH1.Font_Color = CL_WHITE;
                    DrawLabel( &Label_00_00_Indoor_Temperature );
                    DrawLabel( &Label_00_01_Indoor_Ambient_Light_CH0 );
                    DrawLabel( &Label_00_01_Indoor_Ambient_Light_CH1 );

                    Label_00_00_Indoor_Temperature_Caption[0] = 0;
                    Label_00_01_Indoor_Ambient_Light_CH0_Caption[0] = 0;
                    Label_00_01_Indoor_Ambient_Light_CH1_Caption[0] = 0;

                    /**
                     * Set new temperature and als values
                     */
                    FloatToStr( temperature, Label_00_00_Indoor_Temperature_Caption );
                    Ltrim( Label_00_00_Indoor_Temperature_Caption );
                    float_cut( Label_00_00_Indoor_Temperature_Caption );
                    strcat( Label_00_00_Indoor_Temperature_Caption, "  C" );
                    text[0] = 0;
                    strcat( Label_00_01_Indoor_Ambient_Light_CH0_Caption, "Ch 0 : " );
                    WordToStr( channel_0, text );
                    Ltrim( text );
                    strcat( Label_00_01_Indoor_Ambient_Light_CH0_Caption, text );
                    text[0] = 0;
                    strcat( Label_00_01_Indoor_Ambient_Light_CH1_Caption, "Ch 1 : " );
                    WordToStr( channel_1, text );
                    Ltrim( text );
                    strcat( Label_00_01_Indoor_Ambient_Light_CH1_Caption, text );

                    /**
                     * Draw temperature and als labels
                     */
                    Label_00_00_Indoor_Temperature.Font_Color = CL_BLACK;
                    Label_00_01_Indoor_Ambient_Light_CH0.Font_Color = CL_BLACK;
                    Label_00_01_Indoor_Ambient_Light_CH1.Font_Color = CL_BLACK;
                    DrawLabel( &Label_00_00_Indoor_Temperature );
                    DrawLabel( &Label_00_01_Indoor_Ambient_Light_CH0 );
                    DrawLabel( &Label_00_01_Indoor_Ambient_Light_CH1 );
                }
                else
                {
                    i++;
                }

                /**
                 * Check Touch panel
                 */
                Check_TP( );

            #endif

            break;
        }
        default :
        {
            /** 
             * Error
             */
            while (1);
        }
    }
}

/* --------------------------------------------- PRIVATE FUNCTION DEFINITIONS */

static void float_cut( char * text )
{
    uint8_t count;
    uint8_t conCnt = 0;
    uint8_t conVar = 0;

    for (count = 0; count < 30; count++)
    {
        if (text[ count ] == '.')
        {
            conVar = 1;
        }
        if (conVar == 1)
        {
            conCnt++;
        }
        if (conCnt > 3)
        {
            if ((text[ count ] == 'e') || (conVar == 2))
            {
                text[ count - (conCnt - 4) ] = text[ count ];
                text[ count ] = 0;
                conVar = 2;
            }
            else
            {
                text[ count ] = 0;
            }
        }
    }
}