/*
    bsp_als_driver.c

-----------------------------------------------------------------------------

  This file is part of mikroSDK.

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

#include "hal.h"
#include "bsp_als_driver.h"

#if ( _MMB_MODULE_ALS == 1 )

/* ------------------------------------------------------------------- MACROS */

#define ALS_I2C_ADDRESS         0x29

/* ----------------------------------------------------------- IMPLEMENTATION */

void bsp_als_init ( void )
{
    hal_i2c_map( &BSP_ALS_I2C_MODULE );
    hal_als_init( );
    Delay_ms(500);
}

uint8_t bsp_als_read_regs ( uint8_t reg_address, uint8_t * value, uint8_t len )
{
    if ( ( len > 4 ) || ( len == 0 ) )
    {
        return 1;
    }

    hal_i2c_start( );
    hal_i2c_write( ALS_I2C_ADDRESS, &reg_address, 1, END_MODE_RESTART );
    hal_i2c_read( ALS_I2C_ADDRESS, value, len, END_MODE_STOP );

    return 0;
}

uint8_t bsp_als_write_regs ( uint8_t reg_address, uint8_t * value, uint8_t len )
{
    uint8_t tmp[5];    

    if ( ( len > 4 ) || ( len == 0 ) )
    {
        return 1;
    }

    tmp[0] = reg_address;
    
    memcpy( &tmp[1], value, len );

    hal_i2c_start( );
    hal_i2c_write( ALS_I2C_ADDRESS, &tmp, len + 1, END_MODE_STOP );

    return 0;
}

uint8_t bsp_als_read_measurement ( uint16_t * ch0, uint16_t * ch1 )
{
    uint8_t tmp_status;
    uint8_t tmp_read[4];

    bsp_als_read_regs( _BSP_ALS_STATUS_REG, &tmp_status, 1 );

    /**
         Check data ready bit from status register.
    */
    if ( ( tmp_status & 0x04 ) != 0x04 )
    {
        return 1;
    }

    bsp_als_read_regs( _BSP_ALS_DATA_CH1_REG0, &tmp_read, 4 );

    *ch1 = tmp_read[1];
    *ch1 <<= 8;
    *ch1 |= tmp_read[0];

    *ch0 = tmp_read[3];
    *ch0 <<= 8;
    *ch0 |= tmp_read[2];

    return 0;
}

#endif

/* -------------------------------------------------------------------------- */
/*
    bsp_als_driver.c

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgment:
   This product includes software developed by the MikroElektonika.

4. Neither the name of the MikroElektonika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */