/*
    bsp_als_driver.h

-----------------------------------------------------------------------------

  This file is part of mikroSDK.
  
  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

/**
        \file   bsp_als_driver.h

- Circuit               :   LTR-329ALS-01
- Global Library Prefix :   BSP_ALS
- Version               :   1.0.0
- Date                  :   May 2019
- Developer             :   Milos Vidojevic

---

    Last version note :

Module created.

*/
/* -------------------------------------------------------------------------- */

#ifndef _BSP_ALS_H_
#define _BSP_ALS_H_

#include "bsp.h"

#if ( _MMB_MODULE_ALS == 1 )

#define _BSP_ALS_CONTR_REG          ( 0x80 )    // ALS operation mode control SW reset
#define _BSP_ALS_MEAS_REG           ( 0x85 )    // ALS measurement rate in active mode
#define _BSP_ALS_PART_ID_REG        ( 0x86 )    // Part number ID and revision ID
#define _BSP_ALS_MANUFAC_ID_REG     ( 0x87 )    // Manufacturer ID
#define _BSP_ALS_DATA_CH1_REG0      ( 0x88 )    // ALS measurement CH1 data, lower byte
#define _BSP_ALS_DATA_CH1_REG1      ( 0x89 )    // ALS measurement CH1 data, upper byte
#define _BSP_ALS_DATA_CH0_REG0      ( 0x8A )    // ALS measurement CH0 data, lower byte
#define _BSP_ALS_DATA_CH0_REG1      ( 0x8B )    // ALS measurement CH0 data, upper byte
#define _BSP_ALS_STATUS_REG         ( 0x8C )    // ALS data status

#ifdef __cplusplus
extern "C"{
#endif

/**
    Function initialize ALS module.

        \note

    Must be called before usage of any other function found in this module.

*/
void bsp_als_init ( void );

/**
    Function read register of the ALS module.

        \param[out] reg_address - Start register address
        \param[out] value - Pointer to data buffer 
        \param[out] len - number of bytes to read

        \retval 0 - Successful reading / 1 Unsuccessful reading.

        \note

    This is generic function and can be used to read all registers.

*/
uint8_t bsp_als_read_regs ( uint8_t reg_address, uint8_t * value, uint8_t len );

/**
    Function write register of the ALS module.

        \param[out] reg_address - Start register address
        \param[out] value - Pointer to data buffer 
        \param[out] len - number of bytes to write

        \retval 0 - Successful reading / 1 Unsuccessful reading.

        \note

    This is generic function and can be used to write all registers.

*/
uint8_t bsp_als_write_regs ( uint8_t reg_address, uint8_t * value, uint8_t len );

/**
    Read measurements.

        \param[out] ch0 - Channel 0 ADC value
        \param[out] ch1 - Channel 1 ADC value

        \retval 0 - Successful reading / 1 Unsuccessful reading.

    Function read ADC values from the ALS module. 

        \note

    It is necessary to check return value which guarantee that measurements are 
    valid.
*/
uint8_t bsp_als_read_measurement ( uint16_t * ch0, uint16_t * ch1 );

#ifdef __cplusplus
} // extern "C"
#endif
#endif
#endif

/* -------------------------------------------------------------------------- */
/*
    bsp_als_driver.h

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgment:
   This product includes software developed by the MikroElektonika.

4. Neither the name of the MikroElektonika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */