/*
    bsp_ir_driver.c

-----------------------------------------------------------------------------

  This file is part of mikroSDK.

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

#include "hal.h"
#include "bsp_ir_driver.h"

#if ( _MMB_MODULE_IR == 1 )

/* ---------------------------------------------------------------- VARIABLES */

static uint32_t full_bit; 
static uint32_t half_bit;

/* ----------------------------------------------------------- IMPLEMENTATION */

uint8_t bsp_ir_init ( uint32_t baud_rate )
{
    uint32_t q1; 
    uint32_t q2;
    uint16_t temp_word;

    hal_ir_init( );

    q1 = ( Get_Fosc_kHz( ) * 1000 );                //  Clocks per second.
    q2 = baud_rate * _INSTRUCTION_PER_CLOCK * 10;   //  10 - correction for cycles_div_by_10.

    temp_word = q1 / q2;                            //  If division is bigger than 1 byte.

    full_bit = temp_word;                           //  Full_bit in instr. cycles (div with 10).
    q1 %= q2;                                       //  rem.

    /* 
        Round function if rem is bigger than.
    */

    if ( q1 > q2 >> 1 )                             
    {
        /* 
            Half of division -> round result on bigger integer.
        */

        full_bit++;                             
    }

    half_bit = full_bit >> 1;

    if ( half_bit < 7 )                        
    {
        return 1;
    }
    else
    {
        return 0;
    }
}

uint8_t bsp_ir_read ( uint8_t * error )
{
    uint8_t result;
    uint8_t mask;

    *error = 0;
    result = 0;
    mask = 1;

    /* 
        Wait for start bit.

        !!! WARNING - Blocking operation.
    */

    while ( BSP_IR_RX == 1 )
        ;

    Delay_Cyc( half_bit );
    Delay_Cyc( full_bit );

    /* 
        Receiving bits.
    */

    while ( mask )
    {
        if ( BSP_IR_RX == 1 )
        {
            result |= mask;
        }

        mask <<= 1;
        Delay_Cyc( full_bit - 2 );                  //  Compensation period.
    }

    /* 
        Sample stop bit - if bad return error (1).
    */

    *error = !( BSP_IR_RX );

    return result;
}

uint8_t bsp_ir_pin ( void )
{
    return BSP_IR_RX;
}

#endif

/* -------------------------------------------------------------------------- */
/*
    bsp_ir_driver.c

  Copyright (c) 2017, MikroElektronika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgment:
   This product includes software developed by the MikroElektronika.

4. Neither the name of the MikroElektronika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */