/*
    bsp_mp3_driver.c

-----------------------------------------------------------------------------

  This file is part of mikroSDK.

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

#include "hal.h"
#include "bsp_mp3_driver.h"

#if ( _MMB_MODULE_MP3 == 1 )

/* ------------------------------------------------------------------- MACROS */

//  Use this macro to configure module behaviour.

#define MP3_BLOCKING_CALL

/* ----------------------------------------------------------- IMPLEMENTATION */

void bsp_mp3_init ( void )
{
    hal_spi_map( &BSP_MP3_SPI_MODULE );
    hal_mp3_init( );

    BSP_MP3_CS = 1;
    BSP_MP3_DCS = 1;
    
    BSP_MP3_RST = 1;
    Delay_ms(10);
    BSP_MP3_RST = 0;
    Delay_ms(100);
    BSP_MP3_RST = 1;
    
    while ( BSP_MP3_DREQ == 0 );
}

void bsp_mp3_reset ( void )
{
    BSP_MP3_RST = 0;
    Delay_100ms( );
    BSP_MP3_RST = 1;

    /*  
        !!! WARNING 

        Possible blocking operation. 

        Poll DREQ pin and block until module is ready to receive another 
        command.
    */

    while ( BSP_MP3_DREQ == 0 );
}

void bsp_mp3_cmd_write ( uint8_t address, uint16_t input )
{
    uint8_t tmp[ 4 ];

    tmp[ 0 ] = _BSP_MP3_WRITE_CMD;
    tmp[ 1 ] = address;
    tmp[ 2 ] = input >> 8;
    tmp[ 3 ] = input & 0x00FF;

    BSP_MP3_CS = 0;
    hal_spi_write( tmp, 4 );
    BSP_MP3_CS = 1;

    /*  
        !!! WARNING 

        Possible blocking operation. 

        Poll DREQ pin and block until module is ready to receive another 
        command.
    */

    while ( BSP_MP3_DREQ == 0 );
}

uint16_t bsp_mp3_cmd_read ( uint8_t address )
{
    uint8_t tmp_in[ 4 ];
    uint8_t tmp_out[ 4 ];
    uint16_t res;

    tmp_in[ 0 ] = _BSP_MP3_READ_CMD;
    tmp_in[ 1 ] = address;
    tmp_in[ 2 ] = 0;
    tmp_in[ 3 ] = 0;


    BSP_MP3_CS = 0;
    hal_spi_transfer( tmp_in, tmp_out, 4 );
    BSP_MP3_CS = 1;

    res = tmp_out[ 3 ];
    res <<= 8;
    res |= tmp_out[ 4 ];

    /*  
        !!! WARNING 

        Possible blocking operation. 

        Poll DREQ pin and block until module is ready to receive another 
        command.
    */

    while ( BSP_MP3_DREQ == 0 );

    return res;
}

uint8_t bsp_mp3_data_write ( uint8_t input )
{
    uint8_t tmp = input;

#ifdef MP3_BLOCKING_CALL

    BSP_MP3_DCS = 0;
    while ( BSP_MP3_DREQ == 0 );
    
#else
    
    if ( BSP_MP3_DREQ == 0 )
    {
        return 1;
    }

    BSP_MP3_DCS = 0;
    
#endif

    hal_spi_write( &tmp, 1 );
    BSP_MP3_DCS = 1;

    return 0;
}

uint8_t bsp_mp3_data_write32 ( uint8_t * input32 )
{
#ifdef MP3_BLOCKING_CALL

    BSP_MP3_DCS = 0;
    while ( BSP_MP3_DREQ == 0 );

#else

    if ( BSP_MP3_DREQ == 0 )
    {
        return 1;
    }
    
    BSP_MP3_DCS = 0;
    
#endif

    hal_spi_write( input32, 32 );
    BSP_MP3_DCS = 1;

    return 0;
}

#endif

/* -------------------------------------------------------------------------- */
/*
    bsp_mp3_driver.c

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgment:
   This product includes software developed by the MikroElektonika.

4. Neither the name of the MikroElektonika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */