/*
    bsp_rf_driver.h

-----------------------------------------------------------------------------

  This file is part of mikroSDK.
  
  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

/**
        \file   bsp_rf_driver.h

- Circuit               :   nRF24L01+
- Global Library Prefix :   BSP_RF
- Version               :   2.0.0
- Date                  :   May 2019
- Developer             :   Milos Vidojevic

---

    Last version note :

Modified version of library developed by <ihsan@kehribar.me>.

*/
/* -------------------------------------------------------------------------- */

#ifndef _BSP_RF_DRIVER_H_
#define _BSP_RF_DRIVER_H_

#include "bsp.h"

#if ( _MMB_MODULE_RF == 1 )

#include <stdbool.h>
#include <stddef.h>
#include <stdint.h>

#define data            data_
#define rx              rx_


#ifdef __cplusplus
extern "C"{
#endif

/* adjustment functions */

void bsp_rf_init ( void );
void bsp_rf_rx_address ( uint8_t * adr );
void bsp_rf_tx_address ( uint8_t * adr );
void bsp_rf_config ( uint8_t channel, uint8_t pay_length );

/* state check functions */

uint8_t bsp_rf_data_ready ( void );
uint8_t bsp_rf_is_sending ( void );
uint8_t bsp_rf_get_status ( void );
uint8_t bsp_rf_rx_fifo_empty ( void );

/* core TX / RX functions */

void bsp_rf_data_send ( uint8_t * value );
void bsp_rf_data_read ( uint8_t * data );

/* use in dynamic length mode */

uint8_t bsp_rf_payload_length ( void );

/* post transmission analysis */

uint8_t bsp_rf_last_message_status ( void );
uint8_t bsp_rf_retry_count ( void );

/* Returns the payload length */

uint8_t bsp_rf_get_payload_length ( void );

/* power management */

void bsp_rf_rx_power_up ( void );
void bsp_rf_tx_power_up ( void );
void bsp_rf_power_down ( void );

/* low level interface ... */

void bsp_rf_tx_sync ( uint8_t * dataout, uint8_t len );
void bsp_rf_transfer_sync ( uint8_t * dataout, uint8_t * datain, uint8_t len );
void bsp_rf_register_config ( uint8_t reg, uint8_t value );
void bsp_rf_register_read ( uint8_t reg, uint8_t * value, uint8_t len );
void bsp_rf_register_write ( uint8_t reg, uint8_t * value, uint8_t len );

#ifdef __cplusplus
} // extern "C"
#endif
#endif
#endif

/* -------------------------------------------------------------------------- */
/*
    bsp_rf_driver.c

  Copyright (c) 2017, MikroElektronika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgment:
   This product includes software developed by the MikroElektronika.

4. Neither the name of the MikroElektronika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */