/*
    bsp_rgb_driver.h

-----------------------------------------------------------------------------

  This file is part of mikroSDK.
  
  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

/**
        \file   bsp_rgb_driver.h

- Global Library Prefix :   BSP_RGB
- Version               :   1.0.0 
- Date                  :   May 2019
- Developer             :   Milos Vidojevic

---

    Last version note :

Modified version of mikroSDK library adopted to suit needs in case of mikromedia 
development boards.

*/
/* -------------------------------------------------------------------------- */

#ifndef _BSP_RGB_H_
#define _BSP_RGB_H_

#include "bsp.h"

#if ( _MMB_MODULE_RGBLED == 1 )

#ifdef __cplusplus
extern "C"{
#endif

/**
    Function initialize RGB module.

        \note

    Must be called before usage of any other function found in this module.

*/
void bsp_rgb_init ( void );


void bsp_rgb_set_power ( uint8_t pwr );

/**
    Function clears the RGB pwm channels.

        \warning 

    Possible blocking function. 
*/
void bsp_rgb_clear ( void );

/**
    Function sets the red RGB pwm value.

        \param[in] red  light intensity of the red LED, valid values: 0-31

        \retval 0 - Successful operation / 1 Unsuccessful operation.

        \warning 

    Possible blocking function. 
*/
void bsp_rgb_set_red ( uint8_t red );

/**
    Function sets the green RGB pwm value.

        \param[in] green  light intensity of the green LED, valid values: 0-31

        \retval 0 - Successful operation / 1 Unsuccessful operation.

        \warning 

    Possible blocking function. 
*/
void bsp_rgb_set_green ( uint8_t green );

/**
    Function sets the blue RGB pwm value.

        \param[in] blue  light intensity of the blue LED, valid values: 0-31

        \retval 0 - Successful operation / 1 Unsuccessful operation.

        \warning 

    Possible blocking function. 
*/
void bsp_rgb_set_blue ( uint8_t blue );

void bsp_rgb_set_color ( uint16_t color );

#ifdef __cplusplus
} // extern "C"
#endif
#endif
#endif

/* -------------------------------------------------------------------------- */
/*
    bsp_rgb_driver.h

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgment:
   This product includes software developed by the MikroElektonika.

4. Neither the name of the MikroElektonika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */