/*
    bsp_rtc_driver.c

-----------------------------------------------------------------------------

  This file is part of mikroSDK.

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

#include "hal.h"
#include "bsp_rtc_driver.h"

#if ( _MMB_MODULE_RTC == 1 )

/* ----------------------------------------------------------- IMPLEMENTATION */

void bsp_rtc_init ( void )
{
    hal_rtc_init( );
}

void bsp_rtc_get ( rtc_time_t * time )
{
    uint32_t time_r;
    uint32_t date_r;
    

    time_r = RTC_TR;
    date_r = RTC_DR;

    time->sec  = Bcd2Dec( ( uint8_t ) ( time_r & 0x00007f ) );
    time->min  = Bcd2Dec( ( uint8_t ) ( time_r & 0x007f00 ) >> 8 );
    time->hr   = Bcd2Dec( ( uint8_t ) ( time_r & 0x3f0000 ) >> 16 );
    time->ampm = ( uint8_t ) ( time_r & 0x400000 ) >> 22;

    time->d    = Bcd2Dec( ( uint8_t ) ( date_r & 0x0000ff ) );
    time->m    = Bcd2Dec( ( uint8_t ) ( date_r & 0x001f00 ) >> 8 );
    time->y    = Bcd2Dec( ( uint16_t ) ( date_r & 0x3f0000 ) >> 16 );
}

void bsp_rtc_set ( rtc_time_t * time )
{
    uint32_t temp;

    PWR_CR.DBP = 1;

    /*
        Unlock write protection.
        Enter initialization mode.
    */

    RTC_WPR = 0xCA;
    RTC_WPR = 0x53;
    RTC_ISR = 0x00000080;

    while ( RTC_ISR.INITF != 1 )
    {
        //  Nothing to do here.
    }

    RTC_PRER = 0x7f00ff;

    //  Update time register.

    temp |= Dec2Bcd( ( uint32_t ) ( time->sec ) );
    temp |= Dec2Bcd( ( uint32_t ) ( time->min ) << 8 );
    temp |= Dec2Bcd( ( uint32_t ) ( time->hr ) << 16 );
    temp =  ( ( uint32_t ) ( time->ampm ) << 22 );

    RTC_TR = temp;

    //  Update date register.

    temp |= Dec2Bcd( ( uint32_t ) ( time->d ) );
    temp |= Dec2Bcd( ( uint32_t ) ( time->m ) << 8 );
    temp =  Dec2Bcd( ( uint32_t ) ( time->y ) << 16 );


    RTC_DR = temp;

    /*
        Set FMT 12H format.
        Exit initialization mode.
        Enable the write protection for RTC registers.
    */

    RTC_CRbits.FMT = 1;
    RTC_CRbits.WCKSEL = 0;
    RTC_ISR = 0x00000000;
    RTC_WPR = 0xFF;
        //  Nothing to do here.
}

#endif

/* -------------------------------------------------------------------------- */
/*
    bsp_rtc_driver.c

  Copyright (c) 2017, MikroElektronika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgment:
   This product includes software developed by the MikroElektronika.

4. Neither the name of the MikroElektronika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */