/*
    bsp_temp_driver.c

-----------------------------------------------------------------------------

  This file is part of mikroSDK.

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

#include "hal.h"
#include "bsp_temp_driver.h"

#if ( _MMB_MODULE_TEMP == 1 )

/* ------------------------------------------------------------------- MACROS */

#define SAMPLES_DELAY           1
#define SAMPLES_TAKE            16

/* ----------------------------------------------------------- IMPLEMENTATION */

void bsp_temperature_init ( void )
{
    hal_temp_init( );
    hal_adc_map( &BSP_TEMP_ADC_MODULE );
}

float bsp_temperature_read ( void )
{
    float       res;
    uint8_t     i;
    uint32_t    c = 0;

    for ( i = 0; i < SAMPLES_TAKE; ++i )
    {
        c += hal_adc_read( BSP_TEMP_ADC_CHANNEL );

        Delay_ms( SAMPLES_DELAY );
    }

    c /= SAMPLES_TAKE;

    /*  
        !! TODO

        - Recalculate ADC to Celsius. 
        - Check VREF and RESOLUTION.

        Formula taken from : http://starter-kit.nettigo.eu/2010/how-to-measure-temperature-with-arduino-and-mcp9700/
    */

    res = ( float ) c;
    res = ( res * BSP_TEMP_ADC_VREF ) / ( float ) BSP_TEMP_ADC_RESOLUTION;
    res -= 0.5;
    res /= 0.01;

    return res;
}

#endif

/* -------------------------------------------------------------------------- */
/*
    bsp_temp_driver.c

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgment:
   This product includes software developed by the MikroElektonika.

4. Neither the name of the MikroElektonika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */