/*
    hal_cec.h

-----------------------------------------------------------------------------

  This file is part of mikroSDK.

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

#ifndef _HAL_CEC_H_
#define _HAL_CEC_H_

#include "compiler.h"

static hal_spi_write_fp_t        fp_spi_write;                            
static hal_spi_read_fp_t         fp_spi_read;                             

static void hal_spi_map ( const hal_spi_obj_t * spi_obj )
{
    fp_spi_write = spi_obj->spi_write;
    fp_spi_read  = spi_obj->spi_read;
}

static void hal_spi_write ( uint8_t * buf, uint16_t len )
{
    uint8_t *ptr = buf;

    while ( len-- )
    {
        fp_spi_write( *( ptr++ ) );
    }
}

static void hal_spi_read ( uint8_t * buf, uint16_t len )
{
    uint8_t *ptr = buf;

    while ( len-- )
    {
        *( ptr++ ) = fp_spi_read( 0x00 );
    }
}

static void hal_spi_transfer ( uint8_t * buf_in, uint8_t * buf_out, uint16_t len )
{
    uint8_t *in = buf_in;
    uint8_t *out = buf_out;

    while ( len-- )
    {
        *( out++ ) = fp_spi_read( *( in++ ) );
    }
}

static hal_i2c_start_fp_t        fp_i2c_start;                            
static hal_i2c_write_fp_t        fp_i2c_write;                            
static hal_i2c_read_fp_t         fp_i2c_read;                             

static void hal_i2c_map ( const hal_i2c_obj_t * i2c_obj )
{
    fp_i2c_start    = i2c_obj->i2c_start;
    fp_i2c_write    = i2c_obj->i2c_write;
    fp_i2c_read     = i2c_obj->i2c_read;
}

static int hal_i2c_start ( void )
{
    int res = 0;

    res |= fp_i2c_start( );

    return res;
}

static int hal_i2c_write ( uint8_t slaveAddress, uint8_t * pBuf, uint16_t nBytes, uint8_t endMode )
{
    int res = 0;
    uint8_t *ptr = pBuf;

    res |= fp_i2c_write( slaveAddress, ptr, nBytes, endMode );
    
    return res;
}

static int hal_i2c_read ( uint8_t slaveAddress, uint8_t * pBuf, uint16_t nBytes, uint8_t endMode )
{
    int res = 0;
    uint8_t *ptr = pBuf;

    fp_i2c_read( slaveAddress, ptr, nBytes, endMode );
    
    return res;
}

static hal_uart_write_fp_t       fp_uart_write;                           
static hal_uart_read_fp_t        fp_uart_read;                            
static hal_uart_ready_fp_t       fp_uart_ready;                           

static void hal_uart_map ( const hal_uart_obj_t * uart_obj )
{
    fp_uart_write = uart_obj->uart_write;
    fp_uart_read  = uart_obj->uart_read;
    fp_uart_ready = uart_obj->uart_ready;
}

static void hal_uart_write ( uint8_t input )
{
    fp_uart_write( input );
}

static uint8_t hal_uart_read ( void )
{
    return ( uint8_t ) fp_uart_read( );
}

static uint8_t hal_uart_ready ( void )
{
    return ( uint8_t ) fp_uart_ready( );
}

static hal_pwm_duty_fp_t        fp_pwm_set_duty;
static hal_pwm_start_fp_t       fp_pwm_start;
static hal_pwm_stop_fp_t        fp_pwm_stop;

static void hal_pwm_map ( const hal_pwm_obj_t * pwm_obj )
{
    fp_pwm_set_duty = pwm_obj->pwm_duty;
    fp_pwm_start    = pwm_obj->pwm_start;
    fp_pwm_stop     = pwm_obj->pwm_stop;
}

static void hal_pwm_start ( uint32_t channel, uint32_t duty, uint32_t invert, const Module_Struct * module )
{
    ( void ) channel;
    ( void ) * module;

    fp_pwm_set_duty( ( unsigned int ) duty, ( char ) invert );
    fp_pwm_start( );
}

static void hal_pwm_stop ( uint32_t channel )
{
    ( void ) channel;

    fp_pwm_stop( );
}

static hal_adc_read_fp_t        fp_adc_read;
static hal_adc_sample_fp_t      fp_adc_get_sample;

static void hal_adc_map ( const hal_adc_obj_t * adc_obj )
{
    fp_adc_read       = adc_obj->adc_read;
    fp_adc_get_sample = adc_obj->adc_sample;
}

static uint32_t hal_adc_read ( uint32_t channel )
{
    return ( uint32_t ) fp_adc_read( ( unsigned char ) channel );
}

#endif

/* -------------------------------------------------------------------------- */
/*
    hal_cec.h

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgment:
   This product includes software developed by the MikroElektonika.

4. Neither the name of the MikroElektonika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */
