/*
        hal_pic32.h

-----------------------------------------------------------------------------

  This file is part of mikroSDK.

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

#ifndef _HAL_PIC32_H_
#define _HAL_PIC32_H_

#include "compiler.h"

static hal_spi_write_fp_t        fp_spi_write;                            
static hal_spi_read_fp_t         fp_spi_read;                             

static void hal_spi_map ( const hal_spi_obj_t * spi_obj )
{
    fp_spi_write = spi_obj->spi_write;
    fp_spi_read  = spi_obj->spi_read;
}

static void hal_spi_write ( uint8_t * buf, uint16_t len )2
{
    uint8_t *ptr = buf;

    while ( len-- )
    {
        fp_spi_write( *( ptr++ ) );
    }
}

static void hal_spi_read ( uint8_t * buf, uint16_t len )
{
    uint8_t *ptr = buf;

    while ( len-- )
    {
        *( ptr++ ) = fp_spi_read( 0x00 );
    }
}

static void hal_spi_transfer ( uint8_t * buf_in, uint8_t * buf_out, uint16_t len )
{
    uint8_t *in = buf_in;
    uint8_t *out = buf_out;

    while ( len-- )
    {
        *( out++ ) = fp_spi_read( *( in++ ) );
    }
}

#define NACK_BIT                 1
#define ACK_BIT                  0
#define END_MODE_STOP            0
#define END_MODE_RESTART         1
#define END_MODE_NO              2

static hal_i2c_start_fp_t        fp_i2c_start;                             
static hal_i2c_stop_fp_t         fp_i2c_stop;                              
static hal_i2c_restart_fp_t      fp_i2c_restart;                           
static hal_i2c_write_fp_t        fp_i2c_write;                             
static hal_i2c_read_fp_t         fp_i2c_read;                              

static void hal_i2c_map ( const hal_i2c_obj_t * i2c_obj )
{
    fp_i2c_start    = i2c_obj->i2c_start;
    fp_i2c_stop     = i2c_obj->i2c_stop;
    fp_i2c_restart  = i2c_obj->i2c_restart;
    fp_i2c_write    = i2c_obj->i2c_write;
    fp_i2c_read     = i2c_obj->i2c_read;
}

static int hal_i2c_start ( void )
{
    int res = 0;

    res |= fp_i2c_start( );

    return res;
}

static int hal_i2c_write ( uint8_t slaveAddress, uint8_t * pBuf, uint16_t nBytes, uint8_t endMode )
{
    int res = 0;
    uint8_t *ptr = pBuf;

    res |= fp_i2c_write( slaveAddress << 1 );

    while ( nBytes-- )
    {
        res |= fp_i2c_write( *( ptr++ ) );
    }

    if ( endMode == END_MODE_STOP )
    {
        fp_i2c_stop( );
    }
    
    if ( endMode == END_MODE_RESTART )
    {
        fp_i2c_start( );
    }

    return res;
}

static int hal_i2c_read ( uint8_t slaveAddress, uint8_t * pBuf, uint16_t nBytes, uint8_t endMode )
{
    int res = 0;
    uint8_t *ptr = pBuf;

    res |= fp_i2c_write( ( slaveAddress << 1 ) | 1 );

    while ( --nBytes )
    {
        *ptr++ = fp_i2c_read( ACK_BIT );
    }

    *ptr = fp_i2c_read( NACK_BIT );

    if ( endMode == END_MODE_STOP )
    {
        fp_i2c_stop( );
    }

    if ( endMode == END_MODE_RESTART )
    {
        fp_i2c_restart( );
    }

    return res;
}

static hal_uart_write_fp_t       fp_uart_write;                           
static hal_uart_read_fp_t        fp_uart_read;                            
static hal_uart_ready_fp_t       fp_uart_ready;                           

static void hal_uart_map ( const hal_uart_obj_t * uart_obj )
{
    fp_uart_write = uart_obj->uart_write;
    fp_uart_read  = uart_obj->uart_read;
    fp_uart_ready = uart_obj->uart_ready;
}

static void hal_uart_write ( uint8_t input )
{
    fp_uart_write( input );
}

static uint8_t hal_uart_read ( void )
{
    return ( uint8_t ) fp_uart_read( );
}

static uint8_t hal_uart_ready ( void )
{
    return ( uint8_t ) fp_uart_ready( );
}

#endif

/* -------------------------------------------------------------------------- */
/*
    hal_pic32.h

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgment:
   This product includes software developed by the MikroElektonika.

4. Neither the name of the MikroElektonika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */
