/*
    test_console.h

-----------------------------------------------------------------------------

  This file is part of mikroSDK.
  
  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

/**
        \file   test_console.h

- Version               :   1.0.0
- Date                  :   May 2019
- Developer             :   Milos Vidojevic

---

    Test console for mikromedia boards.

*/
/* -------------------------------------------------------------------------- */

#ifndef _TEST_CONSOLE_H_
#define _TEST_CONSOLE_H_

#include "bsp.h"

#define _TEST_SCREEN_
#define _TEST_CONSOLE_

#ifdef _TEST_SCREEN_

#define TEST_SCREEN_LINE_W_OFFSET       5
#define TEST_SCREEN_LINE_H_OFFSET       20          //  Maximum font height.

#ifdef _MIKROMEDIA_4_

#define TEST_SCREEN_W                   480
#define TEST_SCREEN_W_REP_OFF           120           
#define TEST_SCREEN_W_NXT_OFF           240

#define TEST_SCREEN_H                   272
#define TEST_SCREEN_H_TXT_OFF           20   
#define TEST_SCREEN_H_TCH_OFF           220

#endif
#endif


typedef enum
{
    HEX_FORMAT,
    BYTE_FORMAT,
    SIGNED_WORD_FORMAT,
    UNSIGNED_WORD_FORMAT,
    SIGNED_LONG_FORMAT,
    UNSIGNED_LONG_FORMAT,
    FLOAT_FORMAT,
    STRING_FORMAT

} data_format_t;

// -------------------------------------------------------------- IMPLEMETATION

void test_console_write_text ( uint8_t * x );

void test_console_write_line ( uint8_t * x );

uint8_t test_console_read ( void );

void test_console_init ( void );

void test_sequence_start ( void );

void test_sequence_finish ( void );

void test_console_header ( uint8_t * desc );

void test_console_sub_header ( uint8_t * desc, uint8_t * info );

void test_console_operation ( uint8_t step, uint8_t * desc );

void test_console_output ( uint8_t * desc, void * output, data_format_t fmt, uint8_t * fin );

#endif

/* -------------------------------------------------------------------------- */
/*
    test_console.h

  Copyright (c) 2017,  MikroElektronika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgment:
   This product includes software developed by the  MikroElektronika.

4. Neither the name of the  MikroElektronika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */