/*
    als_test.c

-----------------------------------------------------------------------------

  This file is part of mikroSDK.
  
  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

/**
        \file   als_test.c

- Version               :   1.0.0
- Date                  :   May 2019
- Developer             :   Milos Vidojevic

---

    Generated from module test template.

---

    ALS module test.

*/
/* -------------------------------------------------------------------------- */

#include "test_types.h"
#include "test_console.h"

// Include BSP drivers which will be tested.
//  ...

#include "bsp_als_driver.h"

#if ( _MMB_MODULE_ALS == 1 )

#define TASK_DELAY                      200
#define TASK_NAME                       "ALS Test"

//  Declare necessary initialization variables.
//  ...

static uint8_t  ALS_CTRL_REG = 0x01;
static uint8_t  ALS_MEAS_REG = 0x12;

static uint8_t  als_manufac_id;
static uint8_t  als_part_id;
static uint16_t chann0;
static uint16_t chann1;

//  ...

void als_test ( test_param_t * tp )
{    
    switch ( tp->step ) 
    {
        case TEST_PREINIT :
        {
            tp->step = TEST_INIT;
            tp->delay = TASK_DELAY;
            strcpy( tp->name, TASK_NAME );

            break;
        }
        case TEST_INIT :
        {
            //  Initialize BSP module.
            //  ...

            bsp_als_init( );

            //  Perform all necessary post initialization and configuration actions.
            //  ...

            /*
                - Set active mode and start measurements.
                - Configure measurements rate.
                - Read manufacturer ID.
                - Read part ID.
            */

            bsp_als_write_regs( _BSP_ALS_CONTR_REG, &ALS_CTRL_REG, 1 );
            bsp_als_write_regs( _BSP_ALS_MEAS_REG,  &ALS_MEAS_REG, 1 );
            bsp_als_read_regs( _BSP_ALS_MANUFAC_ID_REG, &als_manufac_id, 1 );
            bsp_als_read_regs( _BSP_ALS_PART_ID_REG,    &als_part_id,    1 );

            test_console_output( "Manufacturer ID", ( void * ) &als_manufac_id, STRING_FORMAT, " | " );
            test_console_output( "Part ID", ( void * ) &als_manufac_id, STRING_FORMAT, "\r\n" );
            test_console_write_line( NULL );

            //  ...
            //  End of module initialization.

            tp->step = TEST_TASK;

            break;
        }
        case TEST_TASK :
        {
            
            if ( bsp_als_read_measurement( &chann0 , &chann1 ) == 0)
            {
                test_console_output( "CH 0", ( void * ) &chann0, UNSIGNED_WORD_FORMAT, " | " );
                test_console_output( "CH 1", ( void * ) &chann1, UNSIGNED_WORD_FORMAT, "\r\n" );
                test_console_write_line( NULL );
            }
            else
            {
                test_console_write_line( "ALS data N/A" );
            }

            break;
        }
    }
} 

#endif

/* -------------------------------------------------------------------------- */
/*
    module_test_als.c

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgment:
   This product includes software developed by the MikroElektonika.

4. Neither the name of the MikroElektonika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */