/*
    flash_test.h

-----------------------------------------------------------------------------

  This file is part of mikroSDK.
  
  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

/**
        \file   flash_test.c

- Version               :   1.0.0
- Date                  :   May 2019
- Developer             :   Marko Jovanovic

---

    Generated from module test template.

---

    FLASH module test.

*/
/* -------------------------------------------------------------------------- */

#include "test_types.h"
#include "test_console.h"

// Include BSP drivers which will be tested.
//  ...

#include "bsp_flash_driver.h"

#if ( _MMB_MODULE_FLASH == 1 )

//  Default task delay in ms

#define TASK_DELAY                      5000
#define TASK_NAME                       "FLASH Test"

//  Declare necessary initialization variables.
//  ...

static uint8_t  WRITE_DATA[8] = { 'M', 'I', 'K', 'R', 'O', 'E', 0 };
static uint8_t  read_data[8];

void flash_test ( test_param_t * tp )
{
    switch ( tp->step ) 
    {
        case TEST_PREINIT :
        {
            tp->step = TEST_INIT;
            tp->delay = TASK_DELAY;
            strcpy( tp->name, TASK_NAME );

            break;
        }
        case TEST_INIT :
        {
            //  Initialize BSP module.
            //  ...
        
            ( void ) bsp_flash_init( );
    
            //  ...
            //  End of module initialization.

            tp->step = TEST_TASK;

            break;
        }
        case TEST_TASK :
        {
            uint32_t address = rand( ) + 0x010000;       // Flash start address

            //  Perform all necessary test tasks.
            //  ...

            test_console_operation( 2, "Memory random block Erasing" );

            //  Erase operation.
        
            if ( bsp_flash_block_erase( address ) == FLASH_OK )
            {
                test_console_write_line( "Memory Block Erased" );
            }
            else
            {
                test_console_write_line( "!!! Memory Block Erase Error" );
            }
            Delay_ms( 1000 );

            memset( read_data, 0, 8 );
            test_console_operation( 3, "Memory random address Read" );
        
            //  Read operation.
        
            if ( bsp_flash_read( address, read_data, 8 ) == FLASH_OK )
            {
                test_console_output( "Data", ( void * ) read_data, STRING_FORMAT, "" );
                test_console_write_line( NULL );
            }
            else
            {
                test_console_write_line( "!!! Memory Read Error" );
            }
            Delay_ms( 1000 );

            test_console_operation( 4, "Memory random address Write" );

            //  Write operation.

            if ( bsp_flash_write( address, WRITE_DATA, 8 ) == FLASH_OK )
            {
                test_console_output( "Data", ( void * ) WRITE_DATA, STRING_FORMAT, "" );
                test_console_write_line( NULL );
            }
            else
            {
                test_console_write_line( "!!! Memory Write Error" );
            }
            Delay_ms( 1000 );

            memset( read_data, 0, 8 );
            test_console_operation( 5, "Memory random address Read" );

            //  Read operation.

            if ( bsp_flash_read( address, read_data, 8 ) == FLASH_OK )
            {
                test_console_output( "Data", ( void * ) read_data, STRING_FORMAT, "" );
                test_console_write_line( NULL );
            }
            else
            {
                test_console_write_line( "!!! Memory Read Error" );
            }

            //  ...
            //  End of test task.

            break;
        }
    }
}

#endif

/* -------------------------------------------------------------------------- */
/*
    flash_test.c

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgment:
   This product includes software developed by the MikroElektonika.

4. Neither the name of the MikroElektonika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */