/*
    rf_test.h

-----------------------------------------------------------------------------

  This file is part of mikroSDK.
  
  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

/**
        \file   rf_test.c

- Version               :   1.0.0
- Date                  :   May 2019
- Developer             :   Milos Vidojevic

---

    RF module test.

*/
/* -------------------------------------------------------------------------- */

#include "test_types.h"
#include "test_console.h"

// Include BSP drivers which will be tested.
//  ...

#include "bsp_rf_driver.h"

#if ( _MMB_MODULE_RF == 1 )

#define TASK_DELAY                      100
#define TASK_NAME                       "RF Test"

//  Declare necessary initialization variables.
//  ...

static uint8_t TX_ADDRESS[5] = { 0xE7, 0xE7, 0xE7, 0xE7, 0xE7 };
static uint8_t RX_ADDRESS[5] = { 0xD7, 0xD7, 0xD7, 0xD7, 0xD7 };

static uint8_t rx_buffer[32];

//  ...

void rf_test ( test_param_t * tp )
{
    switch ( tp->step ) 
    {
        case TEST_PREINIT :
        {
            tp->step = TEST_INIT;
            tp->delay = TASK_DELAY;
            strcpy( tp->name, TASK_NAME );

            break;
        }
        case TEST_INIT :
        {
            /*
                Initialize BSP module.

                    - Initialize driver
                    - Set channel 2
                    - Payload 8 bytes
            */

            /* init hardware pins */

            bsp_rf_init( );

            /* Channel #2 , payload length: 4 */
            /* Set the device addresses */

            bsp_rf_config( 2, 8 );
            bsp_rf_tx_address( TX_ADDRESS );
            bsp_rf_rx_address( RX_ADDRESS );
            test_console_operation( 1, "RF Module Configured" );

            //  Perform all necessary post initialization and configuration actions.
            //  ...


            //  ...
            //  End of module initialization.

            tp->step = TEST_TASK;

            break;
        }
        case TEST_TASK :
        {
            //  Perform all necessary test tasks.
            //  ...

            if ( bsp_rf_data_ready( ) != 0 )
            {
                bsp_rf_data_read( rx_buffer );

                if ( rx_buffer[0] != 0 )
                {
                    test_console_output( "Data received", ( void * ) rx_buffer, STRING_FORMAT, "\r\n" );
                }
            }

            //  ...
            //  End of test task.

            break;
        }
    }
} 

#endif

/* -------------------------------------------------------------------------- */
/*
    rf_test.c

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgment:
   This product includes software developed by the MikroElektonika.

4. Neither the name of the MikroElektonika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */