/*
    ui_test.c

-----------------------------------------------------------------------------

  This file is part of mikroSDK.
  
  Copyright (c) 2017,  MikroElektronika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

/**
        \file   ui_test.c

- Version               :   1.0.0
- Date                  :   May 2019
- Developer             :   Milos Vidjevic

---

    Generated from module test template.
    
*/
/* -------------------------------------------------------------------------- */

#include "test_types.h"
#include "test_console.h"

// Include BSP drivers which will be tested.
//  ...

#include "bsp_ui_driver.h"

//  Default task delay in ms

#define TASK_DELAY                      5
#define TASK_NAME                       "UI Test"

//  Declare necessary initialization variables.
//  ...

static uint16_t i = 0;

void ui_test ( test_param_t * tp )
{
    switch ( tp->step ) 
    {
        case TEST_PREINIT :
        {
            tp->step = TEST_INIT;
            tp->delay = TASK_DELAY;
            strcpy( tp->name, TASK_NAME );

            break;
        }
        case TEST_INIT :
        {
            //  Initialize BSP module.
            //  ...

            if ( bsp_ui_init( ) )
            {
                test_console_write_line( "Failed to initialize touch sensor" );

                break;
            }

            //  Perform all necessary post initialization and configuration actions.
            //  ...


            //  ...
            //  End of module initialization.

            test_console_operation( 1, "UI Initialized" );

            tp->step = TEST_TASK;

            break;
        }
        case TEST_TASK :
        {
            uint16_t x;
            uint16_t y;

            /*
                Test Loop.
            */

            //  Update display each 200 cycles.

            if ( !( ++i % ( TASK_DELAY * 100 ) ) )
            {
                switch ( i / ( TASK_DELAY * 100 ) )
                {
                    #ifdef __TI__
                    
                        case 0 : TFT_16bit_Fill_Screen( CL_WHITE_16bit );  break;
                        case 1 : TFT_16bit_Fill_Screen( CL_RED_16bit );    break;
                        case 2 : TFT_16bit_Fill_Screen( CL_BLUE_16bit );   break;
                        case 3 : TFT_16bit_Fill_Screen( CL_GREEN_16bit );  break;
                        case 4 : TFT_16bit_Fill_Screen( CL_YELLOW_16bit ); break;
                        case 5 : TFT_16bit_Fill_Screen( CL_BLACK_16bit );  break;
                        default : i = 0; break;
                    
                    #else
                    
                        case 0 : TFT_Fill_Screen( CL_WHITE );  break;
                        case 1 : TFT_Fill_Screen( CL_RED );    break;
                        case 2 : TFT_Fill_Screen( CL_BLUE );   break;
                        case 3 : TFT_Fill_Screen( CL_GREEN );  break;
                        case 4 : TFT_Fill_Screen( CL_YELLOW ); break;
                        case 5 : TFT_Fill_Screen( CL_BLACK );  break;
                        default : i = 0; break;
                    
                    #endif
                }

                test_console_operation( 2, "Display Color Updated" );
            }

            if ( !bsp_ui_touch_process( &x, &y ) )
            {
                test_console_output( "X",
                                     ( void * ) &x, UNSIGNED_WORD_FORMAT, " | " );
                test_console_output( "Y",
                                     ( void * ) &y, UNSIGNED_WORD_FORMAT, "\r\n" );
            }

            break;
        }
    }
}

/* -------------------------------------------------------------------------- */
/*
    ui_test.c

  Copyright (c) 2017,  MikroElektronika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgment:
   This product includes software developed by the  MikroElektronika.

4. Neither the name of the  MikroElektronika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */