/*
    wifi_test.c

-----------------------------------------------------------------------------

  This file is part of mikroSDK.
  
  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

/**
        \file   wifi_test.c

- Version               :   1.0.0
- Date                  :   May 2019
- Developer             :   Milos Vidojevic

---

    Generated from module test template.

    Hints :

    - Replace "MODULEXXX" with module name.
    - Add declarations to test_main.c under "Test functions declaration" part.
    - Add function calls to test_init and test_task functions.

*/
/* -------------------------------------------------------------------------- */

#include "test_types.h"
#include "test_console.h"

// Include BSP drivers which will be tested.
//  ...

#include <stddef.h>
#include <stdint.h>

#include "api_wifi.h"

#if ( _MMB_MODULE_WIFI == 1 )

#define TASK_DELAY                      10000
#define TASK_NAME                       "WIFI Test"

//  Declare necessary initialization variables.
//  ...

int32_t retVal;

//  ...

void wifi_test ( test_param_t * tp )
{
    switch ( tp->step ) 
    {
        case TEST_PREINIT :
        {
            tp->step = TEST_INIT;
            tp->delay = TASK_DELAY;
            strcpy( tp->name, TASK_NAME );

            break;
        }
        case TEST_INIT :
        {
            //  Initialize BSP module.
            //  ...

            bsp_wifi_init( );

            //  Perform all necessary post initialization and configuration actions.
            //  ...

            retVal = -1;

            //  ...
            //  End of module initialization.

            tp->step = TEST_TASK;

            break;
        }
        case TEST_TASK :
        {
            //  Perform all necessary test tasks.
            //  ...

            retVal = initializeAppVariables( );
            api_wifi_prerror( retVal );

            retVal = configureSimpleLinkToDefaultState( );

            if ( retVal < 0 )
            {
                if ( DEVICE_NOT_IN_STATION_MODE == retVal )
                {
                    test_console_write_line( "Failed to configure the device" );
                }

                return;
            }

            test_console_write_line( "Device is configured in default state" );

            retVal = sl_Start( 0, 0, 0 );

            if ( ( retVal < 0 ) || ( ROLE_STA != retVal ) )
            {
                test_console_write_line( "Failed to start the device" );

                return;
            }

            test_console_write_line( "Device started as STATION" );

            retVal = establishConnectionWithAP( );

            if ( retVal < 0 )
            {
                test_console_write_line( "Failed to establish connection w/ an AP" );

                return;
            }

            test_console_write_line( "Connection established w/ AP and IP is acquired" );

            retVal = getWeather( );

            if ( retVal < 0 )
            {
                test_console_write_line( "Failed to get weather information" );

                return;
            }

            retVal = disconnectFromAP( );

            if ( retVal < 0 )
            {
                test_console_write_line( "Failed to disconnect from AP" );

                return;
            }

            //  ...
            //  End of test task.

            break;
        }
    }
} 

#endif

/* -------------------------------------------------------------------------- */
/*
    wifi_test.c

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgment:
   This product includes software developed by the MikroElektonika.

4. Neither the name of the MikroElektonika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */